==> app-roku-v1.2.0.zip: locale/en_US/translations.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US" sourcelanguage="pt_BR">
<defaultcodec>UTF-8</defaultcodec>
<context>
  <name>default</name>
  <message>
    <source>Usuário</source>
    <translation>User</translation>
  </message>
  <message>
    <source>Senha</source>
    <translation>Password</translation>
  </message>
  <message>
    <source>Pressione Voltar para acessar o menu</source>
    <translation>Press Back to access the menu</translation>
  </message>
  <message>
    <source>Todos os canais</source>
    <translation>All channels</translation>
  </message>
  <message>
    <source>Canais</source>
    <translation>Channels</translation>
  </message>
  <message>
    <source>Perfil</source>
    <translation>Profile</translation>
  </message>
  <message>
    <source>Filmes e Séries</source>
    <translation>Movies and Series</translation>
  </message>
  <message>
    <source>Sair da aplicação</source>
    <translation>Exit the application</translation>
  </message>
  <message>
    <source>Deseja sair da aplicação?</source>
    <translation>Do you want to exit the application?</translation>
  </message>
  <message>
    <source>Sair</source>
    <translation>Exit</translation>
  </message>
  <message>
    <source>Cancelar</source>
    <translation>Cancel</translation>
  </message>
  <message>
    <source>A seguir</source>
    <translation>Up next</translation>
  </message>
  <message>
    <source>Agora</source>
    <translation>Now</translation>
  </message>
  <message>
    <source>Senha Inválida!</source>
    <translation>Invalid Password!</translation>
  </message>
  <message>
    <source>Erro ao carregar conteúdo</source>
    <translation>Error loading content</translation>
  </message>
  <message>
    <source>Não foi possível carregar, tente novamente mais tarde.</source>
    <translation>Unable to load, please try again later.</translation>
  </message>
  <message>
    <source>Logout</source>
    <translation>Logout</translation>
  </message>
  <message>
    <source>Bem vindo</source>
    <translation>Welcome</translation>
  </message>
  <message>
    <source>Selecione o domínio</source>
    <translation>Select the domain</translation>
  </message>
  <message>
    <source>Você deve selelecionar um provedor antes de continuar</source>
    <translation>You must select a provider before continuing</translation>
  </message>
  <message>
    <source>Pesquise pelo seu provedor e o selecione para prosseguir.</source>
    <translation>Search for your provider and select it to proceed.</translation>
  </message>
  <message>
    <source>Digite seu usuário</source>
    <translation>Enter your username</translation>
  </message>
  <message>
    <source>Digite sua senha</source>
    <translation>Enter your password</translation>
  </message>
  <message>
    <source>Confirmação de e-mail</source>
    <translation>Email confirmation</translation>
  </message>
  <message>
    <source>Para acessar o novo conteúdo de filmes, por favor, insira seu e-mail e confirme através do link enviado.</source>
    <translation>To access the new movie content, please enter your email and confirm through the link sent.</translation>
  </message>
  <message>
    <source>Enviar e-mai</source>
    <translation>Send email</translation>
  </message>
  <message>
    <source>Aguarde</source>
    <translation>Wait</translation>
  </message>
  <message>
    <source>Não foi possível carregar os conteúdos, tente novamente mais tarde.</source>
    <translation>It was not possible to load the contents, try again later.</translation>
  </message>
  <message>
    <source>Tentar novamente</source>
    <translation>Try again</translation>
  </message>
  <message>
    <source>Assistir</source>
    <translation>Watch</translation>
  </message>
  <message>
    <source>Duração</source>
    <translation>Duration</translation>
  </message>
  <message>
    <source>Temporada</source>
    <translation>Season</translation>
  </message>
  <message>
    <source>Bom filme!</source>
    <translation>Enjoy the movie!</translation>
  </message>
  <message>
    <source>A compra da mídia</source>
    <translation>The media purchase</translation>
  </message>
  <message>
    <source>foi concluida com sucesso! Aguarde alguns instantes.</source>
    <translation>was completed successfully! Wait a moment.</translation>
  </message>
  <message>
    <source>Não foi possível efetuar a compra</source>
    <translation>It was not possible to make the purchase</translation>
  </message>
  <message>
    <source>não foi concluida!</source>
    <translation>was not completed!</translation>
  </message>
  <message>
    <source>Detalhes</source>
    <translation>Details</translation>
  </message>
  <message>
    <source>Pesquisar</source>
    <translation>Search</translation>
  </message>
  <message>
    <source>Voltar</source>
    <translation>Back</translation>
  </message>
  <message>
    <source>Entrar</source>
    <translation>Enter</translation>
  </message>
  <message>
    <source>Selecione seu provedor de internet</source>
    <translation>Select your internet provider</translation>
  </message>
  <message>
    <source>Próximo</source>
    <translation>Next</translation>
  </message>
  <message>
    <source>Usuário autenticado com sucesso!</source>
    <translation>User authenticated successfully!</translation>
  </message>
  <message>
    <source>Credenciais de acesso inválidas.</source>
    <translation>Invalid access credentials.</translation>
  </message>
  <message>
    <source>Usuário bloqueado.</source>
    <translation>Blocked user.</translation>
  </message>
  <message>
    <source>Máximo de sessões atingidas.</source>
    <translation>Maximum sessions reached.</translation>
  </message>
  <message>
    <source>Erro inesperado, entre em contato com seu provedor de internet.</source>
    <translation>Unexpected error, contact your internet provider.</translation>
  </message>
</context>
</TS>

==> app-roku-v1.3.0.zip: locale/en_US/translations.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US" sourcelanguage="pt_BR">
<defaultcodec>UTF-8</defaultcodec>
<context>
  <name>default</name>
  <message>
    <source>Usuário</source>
    <translation>User</translation>
  </message>
  <message>
    <source>Senha</source>
    <translation>Password</translation>
  </message>
  <message>
    <source>Pressione Voltar para acessar o menu</source>
    <translation>Press Back to access the menu</translation>
  </message>
  <message>
    <source>Todos os canais</source>
    <translation>All channels</translation>
  </message>
  <message>
    <source>Canais</source>
    <translation>Channels</translation>
  </message>
  <message>
    <source>Perfil</source>
    <translation>Profile</translation>
  </message>
  <message>
    <source>Filmes e Séries</source>
    <translation>Movies and Series</translation>
  </message>
  <message>
    <source>Sair da aplicação</source>
    <translation>Exit the application</translation>
  </message>
  <message>
    <source>Deseja sair da aplicação?</source>
    <translation>Do you want to exit the application?</translation>
  </message>
  <message>
    <source>Sair</source>
    <translation>Exit</translation>
  </message>
  <message>
    <source>Cancelar</source>
    <translation>Cancel</translation>
  </message>
  <message>
    <source>A seguir</source>
    <translation>Up next</translation>
  </message>
  <message>
    <source>Agora</source>
    <translation>Now</translation>
  </message>
  <message>
    <source>Senha Inválida!</source>
    <translation>Invalid Password!</translation>
  </message>
  <message>
    <source>Erro ao carregar conteúdo</source>
    <translation>Error loading content</translation>
  </message>
  <message>
    <source>Não foi possível carregar, tente novamente mais tarde.</source>
    <translation>Unable to load, please try again later.</translation>
  </message>
  <message>
    <source>Logout</source>
    <translation>Logout</translation>
  </message>
  <message>
    <source>Bem vindo</source>
    <translation>Welcome</translation>
  </message>
  <message>
    <source>Selecione o domínio</source>
    <translation>Select the domain</translation>
  </message>
  <message>
    <source>Você deve selelecionar um provedor antes de continuar</source>
    <translation>You must select a provider before continuing</translation>
  </message>
  <message>
    <source>Pesquise pelo seu provedor e o selecione para prosseguir.</source>
    <translation>Search for your provider and select it to proceed.</translation>
  </message>
  <message>
    <source>Digite seu usuário</source>
    <translation>Enter your username</translation>
  </message>
  <message>
    <source>Digite sua senha</source>
    <translation>Enter your password</translation>
  </message>
  <message>
    <source>Confirmação de e-mail</source>
    <translation>Email confirmation</translation>
  </message>
  <message>
    <source>Para acessar o novo conteúdo de filmes, por favor, insira seu e-mail e confirme através do link enviado.</source>
    <translation>To access the new movie content, please enter your email and confirm through the link sent.</translation>
  </message>
  <message>
    <source>Enviar e-mai</source>
    <translation>Send email</translation>
  </message>
  <message>
    <source>Aguarde</source>
    <translation>Wait</translation>
  </message>
  <message>
    <source>Não foi possível carregar os conteúdos, tente novamente mais tarde.</source>
    <translation>It was not possible to load the contents, try again later.</translation>
  </message>
  <message>
    <source>Tentar novamente</source>
    <translation>Try again</translation>
  </message>
  <message>
    <source>Assistir</source>
    <translation>Watch</translation>
  </message>
  <message>
    <source>Duração</source>
    <translation>Duration</translation>
  </message>
  <message>
    <source>Temporada</source>
    <translation>Season</translation>
  </message>
  <message>
    <source>Bom filme!</source>
    <translation>Enjoy the movie!</translation>
  </message>
  <message>
    <source>A compra da mídia</source>
    <translation>The media purchase</translation>
  </message>
  <message>
    <source>foi concluida com sucesso! Aguarde alguns instantes.</source>
    <translation>was completed successfully! Wait a moment.</translation>
  </message>
  <message>
    <source>Não foi possível efetuar a compra</source>
    <translation>It was not possible to make the purchase</translation>
  </message>
  <message>
    <source>não foi concluida!</source>
    <translation>was not completed!</translation>
  </message>
  <message>
    <source>Detalhes</source>
    <translation>Details</translation>
  </message>
  <message>
    <source>Pesquisar</source>
    <translation>Search</translation>
  </message>
  <message>
    <source>Voltar</source>
    <translation>Back</translation>
  </message>
  <message>
    <source>Entrar</source>
    <translation>Enter</translation>
  </message>
  <message>
    <source>Selecione seu provedor de internet</source>
    <translation>Select your internet provider</translation>
  </message>
  <message>
    <source>Próximo</source>
    <translation>Next</translation>
  </message>
  <message>
    <source>Usuário autenticado com sucesso!</source>
    <translation>User authenticated successfully!</translation>
  </message>
  <message>
    <source>Credenciais de acesso inválidas.</source>
    <translation>Invalid access credentials.</translation>
  </message>
  <message>
    <source>Usuário bloqueado.</source>
    <translation>Blocked user.</translation>
  </message>
  <message>
    <source>Máximo de sessões atingidas.</source>
    <translation>Maximum sessions reached.</translation>
  </message>
  <message>
    <source>Erro inesperado, entre em contato com seu provedor de internet.</source>
    <translation>Unexpected error, contact your internet provider.</translation>
  </message>
  <message>
    <source>Senha alterada com sucesso.</source>
    <translation>Password changed successfully.</translation>
  </message>
    <message>
    <source>As senhas não conferem</source>
    <translation>Passwords do not match</translation>
  </message>
  <message>
  <source>Erro</source>
  <translation>Error</translation>
</message>
<message>
<source>Sucesso</source>
<translation>Success</translation>
</message>

<message>
<source>Alterar senha para conteúdo adulto</source>
<translation>Change password for adult content</translation>
</message>
<message>
<source>Conteudo adulto</source>
<translation>Adult content</translation>
</message>
<message>
<source>Confirme a senha</source>
<translation>Confirm password</translation>
</message>
<source>Continuar</source>
<translation>Continue</translation>
</message>
<message>
<source>Cancelar</source>
<translation>Cancel</translation>
</message>
</context>
</TS>
